
.defineobjects {
	
	// at this point, we don't know if the rooms have
	// been created, so items are placed later during
	// room definitions.
	// objects are defined in a separate areas since
	// they can be 'spawned' multiple times


	.object: lantern, "Lantern"
	{

		.desc: "A brass oil lantern"

		// value is a seed "stores" or "agents" use 
		// to determine buy/sell prices.
		.value: 25.0
		
		// flags determine what you can do with this
		// object, ie. pick up, drop, eat, use, wear
		// weild, unweild, sell, buy, move ...
		// the '@' sign are useful constants built
		// into the game engine: @get | @drop | @eat | ...
		// or @standardobject, @cursedobject which already
		// define a set group of flags.
		.attributes [ @general ]
		
		// charges - some objects might have limits to usage
		.charges: 0
		
		// decay - some objects decay after a number of turns
		// held.   if used, decay rate is 1/turn
		// decay may also be activated when item is 'used'
		// .decay: 500
	}
	
	.object: stone, "Stone" {
		.desc: "a plain round stone"
		.attributes [ @get | @drop | @use | @examine ]
	}
	
	.object: pen, "pen" {
		.desc: "a dried up fountain pen"
		.value: 1.0
		.charges: 10
		.attributes [ @get | @drop | @use | @examine | @trade ]
	}
	
	.object: buckle, "buckle" {
		.desc: "a tin belt buckle with a carving of a cow's head"
		.value: 10.0
		.attributes [ @get | @drop | @use | @examine | @trade ]	 
	}
	
	.object: rustykey, "Rusty Key" {
		// keys is used automatically
		.desc: "A small rusty key"
		.value: 0.0
		.attributes [ @get | @drop | @examine ]
	}
	
	.object: gold, "Gold" {
		.desc: "Imperial ducats imprinted with the face of Emperor Radian"
		.stack: @unlimited
		.attributes [ @get | @examine ]
	}
	
	.object: dagger, "Rusty dagger" {
		.desc: "A small rusty dagger with worn leather hilt."
		.attributes [ @weaponitem ]
	}

	.object: fountainrope, "rope" {
		.desc: "An old rope, doesn't look too sturdy"
		.attributes [ @examine | @climb ]
		.event: climbRope
	}
	
	.object: potion, "Healing Potion" {
		.desc: "A swirling mass of liquid"
		.attributes [ @drinkitem ]
		.event: drinkPortion
		.value: 400
		.charges: 2
	}
		
	
	.wieldable: sword, "Long Sword" {
		.desc: "A long sword of standard issue."
		.attributes [ @weaponitem ]
		.value: 30
		.damage [ 4, 12 ]	// damage [ min, max ]
		.hand: primary		// choices: primary, secondary, either, both

		// the following are not yet implemented
		// .ac: n			// some wieldable objects may have an armorclass, ie: shield.
		// .charges: n		// ranged weapons may have charges
		// .uses: obj		// weapons with ammunition must have an object for ammunition
		// .range: n		// ranged weapons may have a range.
	}
	
	.wearable: leather, "Leather Armor" {
		.desc: "Cured hide of cow"
		.attributes [ @wearable ]
		.ac: 5		// this value makes wearer harder to 'hit'
		.physical : 1	// this value reduces physical damage when 'hit'
	}
}

.defineagents {
	.monster: 1, "Giant Rat" {
		.desc: "You've never seen one so big!"
		.level: 1	// defined as general guideline of 'monster' strength
		.experience: 15	// defined as a 'seed' value from which real experience reward is calculated
		.health: 10
		.attributes [ @examine | @attack ]

		.temperment: neutral	// -100 to +100 or use neutral, hostile, friendly
		.attack: 1 {			// define 1 attack (up to 4 planned).
			.desc: "Bites"
			.range: 0
			.skill: 35
			.damage [ 1, 3 ]
		}
		.armor {
			.ac: 0				// armor class makes monster harder to hit
			.physical: 0		// reduces physical damage when hit
								// other damage types for future consideration
		}
		

//		.drops [ ]				// future consideration, not yet.
//		.dropclass:				// future consideration, not yet.
	}
}


.defineplayer: "Eku" {
		
		.level: 1	// allows to set starting level
		
		// experience allows to set starting experience, though it is
		// advised to allow the game to determine based on starting level.
		.experience: 0
		
		// special define a characters attributes:
		//[strength, perception, endurance, charisma, intelligence, agility, luck ]
		// for balance, the total stats should equal 40
		.special [ 7, 8, 4, 5, 7, 7, 2 ]

		// the next 2 directives, health and will are provided to allow
		// fine tuning, though it is advised to allow the game to determine
		// them based on attributes.
//		.health: 0	// amount of damage that can be absorbed
//		.will: 0		// optional for use in games with magic/psi power.
		
//		.skills {
			// skill system not yet defined
			// let Arayna decide based on SPECIAL attributes.
//			}

}

.section: drinkPortion {
	.local {
		healval	= 0
	}
	
	.if ( .get(@lastaction) == @drink) {
		
		healval = .get (@player)->health
		healval += 5
		.if ( healval > .get(@player)->maxhealth ) {
			healval = .get(@player)->maxhealth
		}
		.write ( "healval = " , healval )
		.set ( @player, health, healval )
	}

}


.section: climbRope {
	.if ( .get(@lastaction) == @climb) {
		.if ( .get(@area) == level1) {
			.write ( "You climb the rope down into the dark depths" )
			.teleport ( level2, origin2 )
		}
		.else {
			.write ( "You climb the rope up towards a faint glow of light" )
			.teleport ( level1, end )
		}
	}
	
	.write ("after rope event")
}

.section: catacombEvent {
	
}
